@@ -23,7 +23,7 @@ except:
 
 
 MSG_ON = """
-<b>**GeezPyro v{BOT_VER} is back up and running!**ɴ</b>
+<b>**GeezProject v{BOT_VER} is back up and running!**ɴ</b>
 """
 
 async def start_main():
@@ -45,5 +45,6 @@ async def start_main():
     await aiosession.close()
 
 if __name__ == "__main__":
+    print(f"Starting GeezProject - {geez_ver}")
     install()
     loop.run_until_complete(start_main())
